import { Component } from '@angular/core';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import {
  FormControl,
  Validators,
  FormsModule,
  ReactiveFormsModule,
  NgForm,
} from '@angular/forms';
import { MatInputModule } from '@angular/material/input';
import { MatFormFieldModule } from '@angular/material/form-field';
import { merge } from 'rxjs';
import { MatIconModule } from '@angular/material/icon';
import { MatButtonModule } from '@angular/material/button';
import { CommonModule } from '@angular/common';
import { UserService } from 'src/app/services/user.service';
import { User } from 'src/app/models/user.model';

@Component({
  selector: 'app-auth',
  templateUrl: './register.component.html',
  styleUrl: './register.component.css',
  standalone: true,
  imports: [
    MatFormFieldModule,
    MatInputModule,
    FormsModule,
    ReactiveFormsModule,
    MatButtonModule,
    MatIconModule,
    CommonModule,
  ],
})
export class RegisterComponent {
  hide = true;

  email = new FormControl('', [Validators.required, Validators.email]);

  login = new FormControl('', [Validators.required]);

  password = new FormControl('', [Validators.required]);

  errorMessage = '';

  successRegister = '';
  errorRegister = '';

  constructor(private userService: UserService) {
    merge(this.email.statusChanges, this.email.valueChanges)
      .pipe(takeUntilDestroyed())
      .subscribe(() => this.updateErrorMessage());
  }

  updateErrorMessage() {
    if (this.email.hasError('required')) {
      this.errorMessage = 'You must enter a value';
    } else if (this.email.hasError('email')) {
      this.errorMessage = 'Not a valid email';
    } else if (this.login.hasError('required')) {
      this.errorMessage = 'You must enter a login';
    } else {
      this.errorMessage = '';
    }
  }

  register() {
    console.log('registering user :', this.login.value);

    const form: any = {
      value: {
        login: this.login.value,
        password: this.password.value,
      },
    };
    this.userService.postUser(form).subscribe((response) => {
      console.log('response :', response);
      if ((response as any).success) {
        this.successRegister = 'Votre compte a été créé avec succès.';
        this.errorRegister = '';
      } else {
        this.errorRegister =
          "L'inscription a échoué : un compte avec ce login existe déjà.";
        this.successRegister = '';
      }
    });
  }
}
